

### Fixed
- Rewind cursor to before failed chunk so records are not lost on retry
- Revert verbose default back to False in sync cursor handler to match partitioned handler
- Prevent false retries on stream-full 400 errors
- Handle sync_limits_exhausted in orchestrator